@@ -31,6 +31,7 @@
     });
     let counter = 1;
     const AugmentedNotification = Object.assign(class {
+        _id;
         constructor(title, options) {
             // According to https://github.com/sindresorhus/caprine/pull/637, the Notification
             // constructor can be called with non-string title and body.
@@ -40,7 +41,6 @@
             const titleProps = title.props;
             title = titleProps ? titleProps.content[0] : title;
             this._id = counter++;
-            // eslint-disable-next-line @typescript-eslint/no-unsafe-argument
             notifications.set(this._id, this);
             window.postMessage({
                 type: 'notification',
@@ -48,8 +48,8 @@
                     title,
                     id: this._id,
                     ...options,
-                    body
-                }
+                    body,
+                },
             }, '*');
         }
         // No-op, but Messenger expects this method to be present
